# Examples with gadma.Inference.optimize_ga function

Here are two examples of GADMA run from Python for demographic inference of YRI, CEU populations of modern humans. GADMA provides module ``Inference`` with ``optimize_ga`` function. It is similar for ``dadi`` and ``moments`` usual inference with ``Inference.optimize_log`` function. For more information see:

* `YRI_CEU_with_optimize_ga_and_dadi.ipynb` - Notebook with example using ``dadi``.
* `YRI_CEU_with_optimize_ga_and_moments.ipynb` - Notebook with example using ``moments``.

Other files are:

* `YRI_CEU.fs` - Data from Gutenkunst et al. 2009 paper for YRI, CEU populations.
* `demographic_models_dadi.py` - demographic models written with ``dadi``.
* `demographic_models_moments.py` - demographic models written with ``moments``.